pygeodesy.wgrs.Georef

Package pygeodesy :: Module wgrs :: Class Georef |
[frames] | no frames]

# Class Georef

          object --+
                   |
          basestring --+
                       |
                     str --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
               unitsBase.Str --+
                               |
                              Georef

Georef class, a named `str`.

Instance Methods
toLatLon(self, LatLon=None, height=None, **name_LatLon_kwds) Return (the center of) this georef cell as a `LatLon`. |
Inherited from `unitsBase.Str`: `__call__`, `__repr__`, `__str__`, `join_`, `toRepr`, `toStr` Inherited from `str`: `__add__`, `__contains__`, `__eq__`, `__format__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__rmod__`, `__rmul__`, `__sizeof__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `format`, `index`, `isalnum`, `isalpha`, `isdigit`, `islower`, `isspace`, `istitle`, `isupper`, `join`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, lat_gll, lon=None, height=None, precision=3, name='') New Georef from an other Georef instance or georef `str` or from a `LatLon` instance or lat-/longitude `str`. |

Properties
| decoded3 Get this georef's attributes (LatLonPrec3Tuple).
| decoded5 Get this georef's attributes (LatLonPrec5Tuple) with height and radius set to `None` if missing.
| height Get this georef's height in `meter` or `None` if missing.
| latlon Get this georef's (center) lat- and longitude (LatLon2Tuple).
| latlonheight Get this georef's (center) lat-, longitude and height (LatLon3Tuple), with height set to `INT0` if missing.
| precision Get this georef's precision (`int`).
| radius Get this georef's radius in `meter` or `None` if missing.
Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, lat_gll, lon=None, height=None, precision=3, name='') Static Method |
New Georef from an other Georef instance or georef `str` or from a `LatLon` instance or lat-/longitude `str`. Arguments: `lat_gll` - Latitude (`degrees90`), a georef (Georef, `str`) or a location (`LatLon`, `LatLon*Tuple`). `lon` - Logitude (`degrees180)`, required if `lat_gll` is `degrees90`, ignored otherwise. `height` - Optional height in `meter`, used if `lat_gll` is a location. `precision` - The desired georef resolution and length (`int` 0..11), see encode. `name` - Optional name (`str`). Returns: a new object with type S, a subtype of T New Georef. Raises: `RangeError` - Invalid `lat_gll` or `lon`. `TypeError` - Invalid `lat_gll` or `lon`. `WGRSError` - INValid `lat_gll`. Overrides: object.__new__

### toLatLon (self, LatLon=None, height=None, **name_LatLon_kwds) |
Return (the center of) this georef cell as a `LatLon`. Arguments: `LatLon` - Class to use (`LatLon`) or `None`. `height` - Optional height (`meter`), overriding this height. `name_LatLon_kwds` - Optional `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: This georef location (`LatLon`) or if `LatLon is None`, a LatLon3Tuple`(lat, lon, height)`. Raises: `TypeError` - Invalid `LatLon` or `name_LatLon_kwds`.

Property Details

### decoded3 Get this georef's attributes (LatLonPrec3Tuple). Get method: decoded3(self) - Get this georef's attributes (LatLonPrec3Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### decoded5 Get this georef's attributes (LatLonPrec5Tuple) with height and radius set to `None` if missing. Get method: decoded5(self) - Get this georef's attributes (LatLonPrec5Tuple) with height and radius set to `None` if missing. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### height Get this georef's height in `meter` or `None` if missing. Get method: height(self) - Get this georef's height in `meter` or `None` if missing. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get this georef's (center) lat- and longitude (LatLon2Tuple). Get method: latlon(self) - Get this georef's (center) lat- and longitude (LatLon2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlonheight Get this georef's (center) lat-, longitude and height (LatLon3Tuple), with height set to `INT0` if missing. Get method: latlonheight(self) - Get this georef's (center) lat-, longitude and height (LatLon3Tuple), with height set to `INT0` if missing. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### precision Get this georef's precision (`int`). Get method: precision(self) - Get this georef's precision (`int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### radius Get this georef's radius in `meter` or `None` if missing. Get method: radius(self) - Get this georef's radius in `meter` or `None` if missing. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.